package cn.com.qmth.examcloud.core.examwork.service.impl;

import java.io.File;
import java.util.List;

import org.apache.commons.lang3.StringUtils;
import org.apache.poi.ss.usermodel.Sheet;
import org.apache.poi.ss.usermodel.Workbook;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.google.common.collect.Lists;

import cn.com.qmth.examcloud.commons.base.exception.StatusException;
import cn.com.qmth.examcloud.commons.base.helpers.poi.ExcelParser;
import cn.com.qmth.examcloud.core.examwork.dao.ExamStudentTempRepo;
import cn.com.qmth.examcloud.core.examwork.dao.entity.ExamStudentTempEntity;
import cn.com.qmth.examcloud.core.examwork.service.ExamStudentImportService;

/**
 * 类注释
 *
 * @author WANGWEI
 * @date 2018年7月13日
 * @Copyright (c) 2018-? http://qmth.com.cn All Rights Reserved.
 */
@Service
public class ExamStudentImportServiceImpl implements ExamStudentImportService {

	private static final String[] EXCEL_HEADER = new String[]{"姓名", "学号", "身份证号", "学习中心代码",
			"学习中心名称", "课程代码", "课程名称", "试卷类型", "专业", "考点", "信息采集人", "学生电话", "年级"};

	@Autowired
	ExamStudentTempRepo ExamStudentTempRepo;

	@Override
	public void importExamStudent(File file, String fileName) {
		Workbook workBook = ExcelParser.getWorkBook(file, fileName);

		Sheet sheet = workBook.getSheetAt(0);

		List<String[]> lineList = ExcelParser.readSheet(sheet, 13);
		ExcelParser.close(workBook);

		List<ExamStudentTempEntity> list = Lists.newArrayList();
		long currentTimeMillis = System.currentTimeMillis();

		for (int i = 0; i < lineList.size(); i++) {
			String[] line = lineList.get(i);
			if (0 == i) {
				checkExcelHeader(line);
			}

			ExamStudentTempEntity es = new ExamStudentTempEntity();
			es.setBatchId(currentTimeMillis);
			es.setName(trimAndNullIfBlank(line[0]));
			es.setStudentCode(trimAndNullIfBlank(line[1]));
			es.setIdentityNumber(trimAndNullIfBlank(line[2]));
			es.setOrgCode(trimAndNullIfBlank(line[3]));
			es.setOrgName(trimAndNullIfBlank(line[4]));
			es.setCourseCode(trimAndNullIfBlank(line[5]));
			es.setCourseName(trimAndNullIfBlank(line[6]));
			es.setPaperType(trimAndNullIfBlank(line[7]));
			es.setSpecialtyName(trimAndNullIfBlank(line[8]));
			es.setExamSite(trimAndNullIfBlank(line[9]));
			es.setInfoCollector(trimAndNullIfBlank(line[10]));
			es.setPhone(trimAndNullIfBlank(line[11]));
			es.setGrade(trimAndNullIfBlank(line[12]));

			list.add(es);
		}

		ExamStudentTempRepo.save(list);

	}

	/**
	 * 方法注释
	 *
	 * @author WANGWEI
	 * @param s
	 * @return
	 */
	private String trimAndNullIfBlank(String s) {
		if (StringUtils.isBlank(s)) {
			return null;
		}
		return s.trim();
	}

	private void checkExcelHeader(String[] header) {
		for (int i = 0; i < EXCEL_HEADER.length; i++) {
			if (!EXCEL_HEADER[i].equals(header[i].trim())) {
				throw new StatusException("E-651001", "Excel 表头错误");
			}
		}
	}

}
